@@ -206,7 +206,7 @@ class quad2model(object):
         reset()      
         if kargs.has_key('sequence'):
             sequence = kargs['sequence']
-            if sequence.type !='Ideal_pulse':
+            if sequence.type !='ideal_pulse':
                 pass #logger.error('sorry non-ideal pulse not yet implemented')
         fd = kargs['fd']
         nucleus = fd.NUC1[-1]
@@ -402,7 +402,7 @@ class simpsonquad2model(object):
         lb = width * (1.-ratio)        
         if kargs.has_key('sequence'):
             sequence = kargs['sequence']
-            if sequence.type !='Ideal_pulse':
+            if sequence.type !='ideal_pulse':
                 pass #logger.error('sorry non-ideal pulse not yet implemented')
         fd = kargs['fd']
         nucleus = fd.NUC1[-1]
